@@ -35,9 +35,7 @@ impl MessageHandler for NullHandler {
         false
     }
 
-    fn into_output(self, _state: &ParserState) -> Self::Output {
-        ()
-    }
+    fn into_output(self, _state: &ParserState) -> Self::Output {}
 }
 
 #[derive(Clone)]
@@ -96,7 +94,7 @@ impl<'a, T: MessageHandler> DemoHandler<'a, T> {
                     self.handle_string_table(table)
                 }
             }
-            Packet::Message(packet) | Packet::Sigon(packet) => {
+            Packet::Message(packet) | Packet::Signon(packet) => {
                 //self.tick = packet.tick;
                 for message in packet.messages {
                     match message {
