@@ -11,12 +11,12 @@ pub use crate::demo::parser::handler::{DemoHandler, MessageHandler, NullHandler}
 pub use crate::demo::parser::state::ParserState;
 use crate::Stream;
 
-mod analyser;
-mod error;
+pub mod analyser;
+pub mod error;
 pub mod gamestateanalyser;
 pub mod handler;
-mod messagetypeanalyser;
-mod state;
+pub mod messagetypeanalyser;
+pub mod state;
 
 pub use self::error::*;
 use crate::demo::parser::handler::BorrowMessageHandler;
@@ -136,7 +136,7 @@ impl<'a> RawPacketStream<'a> {
                     Ok(Some(packet))
                 }
                 Ok(packet) => Ok(Some(packet)),
-                Err(ParseError::ReadError(BitError::NotEnoughData { .. })) if false => {
+                Err(ParseError::ReadError(BitError::NotEnoughData { .. })) => {
                     self.ended = true;
                     self.incomplete = true;
                     Ok(None)
